#########################
## IMPORT DEPENDENCIES ##
#########################
import plotly.graph_objects as go
import plotly.io as pio
import base64

######################
## THEME DEFINITION ##
######################
pio.templates['mmp_theme'] = go.layout.Template({
    'data': {'bar': [{'error_x': {'color': '#000000', 'thickness': 2, 'width': 5},
                      'error_y': {'color': '#000000', 'thickness': 2, 'width': 5},
                      'marker': {'line': {'color': 'white', 'width': 0.5},
                                 'pattern': {'fillmode': 'overlay', 'size': 10, 'solidity': 0.2}},
                      'type': 'bar'}],
             'barpolar': [{'marker': {'line': {'color': 'white', 'width': 0.5},
                                      'pattern': {'fillmode': 'overlay', 'size': 10, 'solidity': 0.2}},
                           'type': 'barpolar'}],
             'carpet': [{'aaxis': {'endlinecolor': '#2a3f5f',
                                   'gridcolor': '#C8D4E3',
                                   'linecolor': '#C8D4E3',
                                   'minorgridcolor': '#C8D4E3',
                                   'startlinecolor': '#2a3f5f'},
                         'baxis': {'endlinecolor': '#2a3f5f',
                                   'gridcolor': '#C8D4E3',
                                   'linecolor': '#C8D4E3',
                                   'minorgridcolor': '#C8D4E3',
                                   'startlinecolor': '#2a3f5f'},
                         'type': 'carpet'}],
             'choropleth': [{'colorbar': {'outlinewidth': 0, 'ticks': ''}, 'type': 'choropleth'}],
             'contour': [{'colorbar': {'outlinewidth': 0, 'ticks': ''},
                          'colorscale': [[0.0, '#0d0887'],
                                         [0.1111111111111111, '#46039f'],
                                         [0.2222222222222222, '#7201a8'],
                                         [0.3333333333333333, '#9c179e'],
                                         [0.4444444444444444, '#bd3786'],
                                         [0.5555555555555556, '#d8576b'],
                                         [0.6666666666666666, '#ed7953'],
                                         [0.7777777777777778, '#fb9f3a'],
                                         [0.8888888888888888, '#fdca26'],
                                         [1.0, '#f0f921']],
                          'type': 'contour'}],
             'contourcarpet': [{'colorbar': {'outlinewidth': 0, 'ticks': ''}, 'type': 'contourcarpet'}],
             'heatmap': [{'colorbar': {'outlinewidth': 0, 'ticks': ''},
                          'colorscale': [[0.0, '#0d0887'],
                                         [0.1111111111111111, '#46039f'],
                                         [0.2222222222222222, '#7201a8'],
                                         [0.3333333333333333, '#9c179e'],
                                         [0.4444444444444444, '#bd3786'],
                                         [0.5555555555555556, '#d8576b'],
                                         [0.6666666666666666, '#ed7953'],
                                         [0.7777777777777778, '#fb9f3a'],
                                         [0.8888888888888888, '#fdca26'],
                                         [1.0, '#f0f921']],
                          'type': 'heatmap'}],
             'heatmapgl': [{'colorbar': {'outlinewidth': 0, 'ticks': ''},
                            'colorscale': [[0.0, '#0d0887'],
                                           [0.1111111111111111, '#46039f'],
                                           [0.2222222222222222, '#7201a8'],
                                           [0.3333333333333333, '#9c179e'], 
                                           [0.4444444444444444, '#bd3786'],
                                           [0.5555555555555556, '#d8576b'],
                                           [0.6666666666666666, '#ed7953'],
                                           [0.7777777777777778, '#fb9f3a'],
                                           [0.8888888888888888, '#fdca26'],
                                           [1.0, '#f0f921']],
                            'type': 'heatmapgl'}],
             'histogram': [{'marker': {'pattern': {'fillmode': 'overlay', 'size': 10, 'solidity': 0.2}},
                            'type': 'histogram'}],
             'histogram2d': [{'colorbar': {'outlinewidth': 0, 'ticks': ''},
                              'colorscale': [[0.0, '#0d0887'],
                                             [0.1111111111111111, '#46039f'],
                                             [0.2222222222222222, '#7201a8'],
                                             [0.3333333333333333, '#9c179e'],
                                             [0.4444444444444444, '#bd3786'],
                                             [0.5555555555555556, '#d8576b'],
                                             [0.6666666666666666, '#ed7953'],
                                             [0.7777777777777778, '#fb9f3a'],
                                             [0.8888888888888888, '#fdca26'], 
                                             [1.0, '#f0f921']],
                              'type': 'histogram2d'}],
             'histogram2dcontour': [{'colorbar': {'outlinewidth': 0, 'ticks': ''},
                                     'colorscale': [[0.0, '#0d0887'],
                                                    [0.1111111111111111, '#46039f'],
                                                    [0.2222222222222222, '#7201a8'],
                                                    [0.3333333333333333, '#9c179e'],
                                                    [0.4444444444444444, '#bd3786'],
                                                    [0.5555555555555556, '#d8576b'],
                                                    [0.6666666666666666, '#ed7953'],
                                                    [0.7777777777777778, '#fb9f3a'],
                                                    [0.8888888888888888, '#fdca26'],
                                                    [1.0, '#f0f921']],
                                     'type': 'histogram2dcontour'}],
             'mesh3d': [{'colorbar': {'outlinewidth': 0, 'ticks': ''}, 'type': 'mesh3d'}],
             'parcoords': [{'line': {'colorbar': {'outlinewidth': 0, 'ticks': ''}}, 'type': 'parcoords'}],
             'pie': [{'automargin': True, 'type': 'pie'}],
             'scatter': [{'marker': {'colorbar': {'outlinewidth': 0, 'ticks': ''}}, 'type': 'scatter'}],
             'scatter3d': [{'line': {'colorbar': {'outlinewidth': 0, 'ticks': ''}},
                            'marker': {'colorbar': {'outlinewidth': 0, 'ticks': ''}},
                            'type': 'scatter3d'}],
             'scattercarpet': [{'marker': {'colorbar': {'outlinewidth': 0, 'ticks': ''}}, 'type': 'scattercarpet'}],
             'scattergeo': [{'marker': {'colorbar': {'outlinewidth': 0, 'ticks': ''}}, 'type': 'scattergeo'}],
             'scattergl': [{'marker': {'colorbar': {'outlinewidth': 0, 'ticks': ''}}, 'type': 'scattergl'}],
             'scattermapbox': [{'marker': {'colorbar': {'outlinewidth': 0, 'ticks': ''}}, 'type': 'scattermapbox'}],
             'scatterpolar': [{'marker': {'colorbar': {'outlinewidth': 0, 'ticks': ''}}, 'type': 'scatterpolar'}],
             'scatterpolargl': [{'marker': {'colorbar': {'outlinewidth': 0, 'ticks': ''}}, 'type': 'scatterpolargl'}],
             'scatterternary': [{'marker': {'colorbar': {'outlinewidth': 0, 'ticks': ''}}, 'type': 'scatterternary'}],
             'surface': [{'colorbar': {'outlinewidth': 0, 'ticks': ''},
                          'colorscale': [[0.0, '#0d0887'],
                                         [0.1111111111111111, '#46039f'],
                                         [0.2222222222222222, '#7201a8'],
                                         [0.3333333333333333, '#9c179e'],
                                         [0.4444444444444444, '#bd3786'],
                                         [0.5555555555555556, '#d8576b'],
                                         [0.6666666666666666, '#ed7953'],
                                         [0.7777777777777778, '#fb9f3a'],
                                         [0.8888888888888888, '#fdca26'],
                                         [1.0, '#f0f921']],
                          'type': 'surface'}],
             'table': [{'cells': {'fill': {'color': '#EBF0F8'}, 'line': {'color': 'white'}},
                        'header': {'fill': {'color': '#C8D4E3'}, 'line': {'color': 'white'}},
                        'type': 'table'}],
    },
    'layout': {'annotationdefaults': {'arrowcolor': '#2a3f5f', 'arrowhead': 0, 'arrowwidth': 1},
               'autotypenumbers': 'strict',
               'coloraxis': {'colorbar': {'outlinewidth': 0, 'ticks': ''}},
               'colorscale': {'diverging': [[0, '#8e0152'], [0.1, '#c51b7d'],
                                            [0.2, '#de77ae'], [0.3, '#f1b6da'],
                                            [0.4, '#fde0ef'], [0.5, '#f7f7f7'],
                                            [0.6, '#e6f5d0'], [0.7, '#b8e186'],
                                            [0.8, '#7fbc41'], [0.9, '#4d9221'],
                                            [1, '#276419']],
                              'sequential': [[0.0, '#0d0887'],
                                             [0.1111111111111111, '#46039f'],
                                             [0.2222222222222222, '#7201a8'],
                                             [0.3333333333333333, '#9c179e'],
                                             [0.4444444444444444, '#bd3786'],
                                             [0.5555555555555556, '#d8576b'],
                                             [0.6666666666666666, '#ed7953'],
                                             [0.7777777777777778, '#fb9f3a'],
                                             [0.8888888888888888, '#fdca26'],
                                             [1.0, '#f0f921']],
                              'sequentialminus': [[0.0, '#0d0887'],
                                                  [0.1111111111111111, '#46039f'],
                                                  [0.2222222222222222, '#7201a8'],
                                                  [0.3333333333333333, '#9c179e'],
                                                  [0.4444444444444444, '#bd3786'],
                                                  [0.5555555555555556, '#d8576b'],
                                                  [0.6666666666666666, '#ed7953'],
                                                  [0.7777777777777778, '#fb9f3a'],
                                                  [0.8888888888888888, '#fdca26'],
                                                  [1.0, '#f0f921']]},
               'colorway': ['#1F77B4', '#FF7F0E', '#2CA02C', '#D62728', '#9467BD', '#8C564B',
                            '#E377C2', '#7F7F7F', '#BCBD22', '#17BECF'],
               'font': {'color': '#06476a', 'family': 'Comfortaa', 'size': 18},
               'geo': {'bgcolor': 'white',
                       'lakecolor': 'white',
                       'landcolor': 'white',
                       'showlakes': True,
                       'showland': True,
                       'subunitcolor': '#C8D4E3'},
               'hoverlabel': {'align': 'left'},
               'hovermode': 'closest',
               # 'images': [{'name': "mmplogo",
               #             #'source': 'data:image/png;base64,{}'.format(base64.b64encode(open("logo-mmp.png", 'rb').read()).decode()),
               #             'source': 'https://encrypted-tbn0.gstatic.com/images?q=tbn:ANd9GcR0jzWIeErdFL-8S2ar0Y9RNfMOquBwQ_QT8A&usqp=CAU',
               #             'xref': "paper", 'yref': "paper",
               #             'x': 1, 'y': 1.01,
               #             'sizex':1, 'sizey': 0.12,
               #             'xanchor': "right", 'yanchor': "bottom",
               #             'opacity':1, 'visible':True},
               #             {'name': "additionallogo",
               #             'source': "https://images.plot.ly/language-icons/api-home/python-logo.png",
               #             'xref': "paper", 'yref': "paper",
               #             'x': 0.9, 'y': 1,
               #             'sizex':0.1, 'sizey': 0.15,
               #             'xanchor': "right", 'yanchor': "bottom",
               #             'opacity':1, 'visible':True}
               #              ],
               'mapbox': {'style': 'light'},
               'paper_bgcolor': 'white',
               'plot_bgcolor': 'white',
               'polar': {'angularaxis': {'gridcolor': '#EBF0F8', 'linecolor': '#EBF0F8', 'ticks': ''},
                         'bgcolor': 'white',
                         'radialaxis': {'gridcolor': '#EBF0F8', 'linecolor': '#EBF0F8', 'ticks': ''}},
               'scene': {'xaxis': {'backgroundcolor': 'white',
                                   'gridcolor': '#DFE8F3',
                                   'gridwidth': 3,
                                   'linecolor': '#EBF0F8',
                                   'showbackground': True,
                                   'ticks': 'outside',
                                   'zerolinecolor': '#EBF0F8'},
                         'yaxis': {'backgroundcolor': 'white',
                                   'gridcolor': '#DFE8F3',
                                   'gridwidth': 3,
                                   'linecolor': '#EBF0F8',
                                   'showbackground': True,
                                   'ticks': '',
                                   'zerolinecolor': '#EBF0F8'},
                         'zaxis': {'backgroundcolor': 'white',
                                   'gridcolor': '#DFE8F3',
                                   'gridwidth': 3,
                                   'linecolor': '#EBF0F8',
                                   'showbackground': True,
                                   'ticks': '',
                                   'zerolinecolor': '#EBF0F8'}},
               'shapedefaults': {'line': {'color': '#2a3f5f'}},
               'ternary': {'aaxis': {'gridcolor': '#DFE8F3', 'linecolor': '#A2B1C6', 'ticks': ''},
                           'baxis': {'gridcolor': '#DFE8F3', 'linecolor': '#A2B1C6', 'ticks': ''},
                           'bgcolor': 'white',
                           'caxis': {'gridcolor': '#DFE8F3', 'linecolor': '#A2B1C6', 'ticks': ''}},
               'title': {'x': 0.05, 'font': {'family': 'Comfortaa', 'size': 25, 'color': '#06476a'}},#, 'text': ''},
               'xaxis': {'automargin': True,
                         'gridcolor': '#9dddf0',
                         'linecolor': '#9dddf0',
                         'ticks': 'outside',
                         'tickfont': {'family': 'Comfortaa', 'size': 18},
                         'title': {'standoff': 15, 'font': {'family': 'Comfortaa', 'size': 20}},
                         'zerolinecolor': '#9dddf0',
                         'zerolinewidth': 1},
               'yaxis': {'automargin': True,
                         'gridcolor': '#9dddf0',
                         'linecolor': '#9dddf0',
                         'ticks': 'outside',
                         'tickfont': {'family': 'Comfortaa', 'size': 18},
                         'title': {'standoff': 15, 'font': {'family': 'Comfortaa', 'size': 20}},
                         'zerolinecolor': '#9dddf0',
                         'zerolinewidth': 1},
               'width': 1500,
               'height': 900},
               
})

##########################
## SET THEME AS DEFAULT ##
##########################
pio.templates.default = 'mmp_theme'

